//---------------------------------------------------------------------------
//    $Id: fe_poly.cc 23709 2011-05-17 04:34:08Z bangerth $
//    Version: $Name$
//
//    Copyright (C) 2004, 2005, 2006 by the deal.II authors
//
//    This file is subject to QPL and may not be  distributed
//    without copyright and license information. Please refer
//    to the file deal.II/doc/license.html for the  text  and
//    further information on this license.
//
//---------------------------------------------------------------------------

#include <deal.II/base/qprojector.h>
#include <deal.II/base/tensor_product_polynomials.h>
#include <deal.II/base/polynomials_p.h>
#include <deal.II/fe/fe_poly.h>
#include <deal.II/fe/fe_values.h>

#include <deal.II/fe/fe_poly.templates.h>

DEAL_II_NAMESPACE_OPEN

#include "fe_poly.inst"

DEAL_II_NAMESPACE_CLOSE
